==> meteor-bootstrap_key-value-tag-input-2.3.0.tgz: package/src/keyValueTypes/NumberModifierKeyValueType.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { KeyValueType } from "./KeyValueType";
import { Meteor } from "meteor/meteor";
import { escapeRegexChars } from "../helpers/strings";
var symbolForOperator = {
    "=": "=",
    "*": "*",
    "/": "÷",
    "+": "+",
    "-": "-",
};
var operatorsAndSymbols = ["=", "*", "/", "+", "-", "÷"];
function toSymbol(op) {
    // @ts-ignore missing index signature of mapped type
    return symbolForOperator[op] || op;
}
var NumberModifierKeyValueType = /** @class */ (function (_super) {
    __extends(NumberModifierKeyValueType, _super);
    function NumberModifierKeyValueType() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._delimiters = {
            decimal: ".",
            groups: ",",
        };
        _this._groupsDelimiterRegex = /,/gi;
        return _this;
    }
    NumberModifierKeyValueType.apply = function (value, number, roundMode) {
        if (roundMode === void 0) { roundMode = "not"; }
        var result;
        switch (value.operator) {
            case "=":
                result = value.number;
                break;
            case "*":
                result = number * value.number;
                break;
            case "/":
                result = number / value.number;
                break;
            case "+":
                result = number + value.number;
                break;
            case "-":
                result = number - value.number;
                break;
            default:
                throw new Meteor.Error("invalid-number-modifier", "'" + value.operator + "' is not a valid operation on numbers.");
        }
        switch (roundMode) {
            case "up":
                result = Math.ceil(result);
                break;
            case "down":
                result = Math.floor(result);
                break;
            case "math":
                result = Math.round(result);
                break;
            case "not":
            default:
            // no rounding
        }
        return result;
    };
    Object.defineProperty(NumberModifierKeyValueType.prototype, "delimiters", {
        set: function (delimiters) {
            this._delimiters = delimiters;
            this._groupsDelimiterRegex = new RegExp(escapeRegexChars(this._delimiters.groups), "gi");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberModifierKeyValueType.prototype, "numberFormatter", {
        set: function (numberFormatter) {
            this._numberFormatter = numberFormatter;
        },
        enumerable: true,
        configurable: true
    });
    NumberModifierKeyValueType.prototype.getSuggestions = function (prefix) {
        var _this = this;
        var parsed = this.parseString(prefix);
        // empty input or invalid input or fallback "="
        if (prefix === "" || !parsed || (parsed.operator === "=" && !prefix.startsWith("="))) {
            var number_1 = 42;
            var operators = Object.keys(symbolForOperator);
            if (prefix !== "") {
                number_1 = parsed ? parsed.number : number_1;
                var filteredOperators = operatorsAndSymbols.filter(function (op) { return op.startsWith(prefix); });
                operators = filteredOperators.length > 0 ? filteredOperators : operators;
            }
            return operators.map(function (operator) { return ({
                display: _this.display({ operator: operator, number: number_1 }),
                value: _this.editText({ operator: operator, number: number_1 }),
            }); });
        }
        else {
            return [];
        }
    };
    NumberModifierKeyValueType.prototype.parseString = function (val) {
        var value = val.trim();
        if (value === "") {
            return undefined;
        }
        value = value.replace(/\s/g, "") // remove spaces
            .replace(this._groupsDelimiterRegex, "") // remove grouping delimiters
            .replace(this._delimiters.decimal, "."); // convert to decimal point
        var match = value.replace("÷", "/")
            .match(/^([=*/+-])?(-?\d*\.?\d+)/);
        if (match) {
            return {
                operator: match[1] || "=",
                number: Number(match[2]),
            };
        }
        else {
            return undefined;
        }
    };
    NumberModifierKeyValueType.prototype.checkValue = function (val) {
        if (Object.keys(symbolForOperator).includes(val.operator) && typeof val.number === "number") {
            return val;
        }
        else {
            return undefined;
        }
    };
    NumberModifierKeyValueType.prototype.display = function (value) {
        var numberString = this._numberFormatter ? this._numberFormatter.format(value.number) : String(value.number);
        return { text: toSymbol(value.operator) + " " + numberString };
    };
    NumberModifierKeyValueType.prototype.editText = function (value) {
        return this.display(value).text;
    };
    return NumberModifierKeyValueType;
}(KeyValueType));
export default NumberModifierKeyValueType;

==> meteor-bootstrap_key-value-tag-input-2.5.2.tgz: package/src/keyValueTypes/NumberModifierKeyValueType.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { mathOperators, mathOpsAndSymbols, mathOpToSymbol } from "../helpers/operators";
import { KeyValueType } from "./KeyValueType";
import { Meteor } from "meteor/meteor";
import { escapeRegexChars } from "../helpers/strings";
var NumberModifierKeyValueType = /** @class */ (function (_super) {
    __extends(NumberModifierKeyValueType, _super);
    function NumberModifierKeyValueType() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._delimiters = {
            decimal: ".",
            groups: ",",
        };
        _this._groupsDelimiterRegex = /,/gi;
        return _this;
    }
    NumberModifierKeyValueType.apply = function (value, number, roundMode) {
        if (roundMode === void 0) { roundMode = "not"; }
        var result;
        switch (value.operator) {
            case "=":
                result = value.number;
                break;
            case "*":
                result = number * value.number;
                break;
            case "/":
                result = number / value.number;
                break;
            case "+":
                result = number + value.number;
                break;
            case "-":
                result = number - value.number;
                break;
            default:
                throw new Meteor.Error("invalid-number-modifier", "'" + value.operator + "' is not a valid operation on numbers.");
        }
        switch (roundMode) {
            case "up":
                result = Math.ceil(result);
                break;
            case "down":
                result = Math.floor(result);
                break;
            case "math":
                result = Math.round(result);
                break;
            case "not":
            default:
            // no rounding
        }
        return result;
    };
    Object.defineProperty(NumberModifierKeyValueType.prototype, "delimiters", {
        set: function (delimiters) {
            this._delimiters = delimiters;
            this._groupsDelimiterRegex = new RegExp(escapeRegexChars(this._delimiters.groups), "gi");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberModifierKeyValueType.prototype, "numberFormatter", {
        set: function (numberFormatter) {
            this._numberFormatter = numberFormatter;
        },
        enumerable: true,
        configurable: true
    });
    NumberModifierKeyValueType.prototype.getSuggestions = function (prefix) {
        var _this = this;
        var parsed = this.parseString(prefix);
        // empty input or invalid input or fallback "="
        if (prefix === "" || !parsed || (parsed.operator === "=" && !prefix.startsWith("="))) {
            var number_1 = 42;
            var operators = Object.keys(mathOperators);
            if (prefix !== "") {
                number_1 = parsed ? parsed.number : number_1;
                var filteredOperators = mathOpsAndSymbols.filter(function (op) { return op.startsWith(prefix); });
                operators = filteredOperators.length > 0 ? filteredOperators : operators;
            }
            return operators.map(function (operator) { return ({
                display: _this.display({ operator: operator, number: number_1 }),
                value: _this.editText({ operator: operator, number: number_1 }),
            }); });
        }
        else {
            return [];
        }
    };
    NumberModifierKeyValueType.prototype.parseString = function (val) {
        var value = val.trim();
        if (value === "") {
            return undefined;
        }
        value = value.replace(/\s/g, "") // remove spaces
            .replace(this._groupsDelimiterRegex, "") // remove grouping delimiters
            .replace(this._delimiters.decimal, "."); // convert to decimal point
        var match = value.replace("÷", "/")
            .match(/^([=*/+-])?(-?\d*\.?\d+)/);
        if (match) {
            return {
                operator: match[1] || "=",
                number: Number(match[2]),
            };
        }
        else {
            return undefined;
        }
    };
    NumberModifierKeyValueType.prototype.checkValue = function (val) {
        if (Object.keys(mathOperators).includes(val.operator) && typeof val.number === "number") {
            return val;
        }
        else {
            return undefined;
        }
    };
    NumberModifierKeyValueType.prototype.display = function (value) {
        var numberString = this._numberFormatter ? this._numberFormatter.format(value.number) : String(value.number);
        return { text: mathOpToSymbol(value.operator) + " " + numberString };
    };
    NumberModifierKeyValueType.prototype.editText = function (value) {
        return this.display(value).text;
    };
    return NumberModifierKeyValueType;
}(KeyValueType));
export default NumberModifierKeyValueType;
